authproxy

package
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 3, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package authproxy runs a local HTTP reverse proxy with optional HTTP Basic Auth in front of the app before the tunnel connects.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Server

type Server struct {
	Port int
	// contains filtered or unexported fields
}

Server is a localhost reverse proxy, optionally protected by Basic Auth.

func Start

func Start(targetPort int, user, password string) (*Server, error)

Start listens on 127.0.0.1:0 and forwards to localhost:targetPort. If password is non-empty, clients must send Basic Auth (user defaults to "solo").

func (*Server) Stop

func (s *Server) Stop()

Stop shuts down the proxy server.

Jump to