Documentation
¶
Overview ¶
Package authproxy runs a local HTTP reverse proxy with optional HTTP Basic Auth in front of the app before the tunnel connects.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
Port int
// contains filtered or unexported fields
}
Server is a localhost reverse proxy, optionally protected by Basic Auth.
Click to show internal directories.
Click to hide internal directories.